@@ -3,7 +3,7 @@
  * the GUI elements. 
  */
 
-/* (c) 1998 by Keith Wesolowski (wesolows@cs.unr.edu) 
+/* (c) 1998-2000 by Keith Wesolowski (wesolows@foobazco.org)
 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -199,7 +199,7 @@ void gradio_about_cb (GtkWidget *w, gpointer *data)
     gtk_box_pack_start (GTK_BOX (vbox), sep, TRUE, FALSE ,0);
     for (i=0; i<6; i++)
 	hbox[i] = gtk_hbox_new (FALSE, 0);
-    label[0] = gtk_label_new ("   Author: Keith Wesolowski (wesolows@cs.unr.edu)   ");
+    label[0] = gtk_label_new ("   Author: Keith Wesolowski (wesolows@foobazco.org)   ");
     label[1] = gtk_label_new ("   (c)1998 Keith Wesolowski   ");
     label[2] = gtk_label_new ("   Portions (c)1996 Thomas Lehmann, Gideon LaGrange, and Frans Brinkman.   ");
     label[3] = gtk_label_new ("   This program is distributed under the terms of the GNU General Public License.   ");
