@@ -2,7 +2,7 @@
  * Contains prototypes and some useful constant definition
  */
 
-/* (c) 1998 by Keith Wesolowski (wesolows@cs.unr.edu) 
+/* (c) 1998-2000 by Keith Wesolowski (wesolows@foobazco.org)
 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@
 /* Archaic (2.0.x) kernels don't have KERNEL_VERSION_CODE, so
  * the value is hard-coded (2.1.106).
  */
-#if (LINUX_VERSION_CODE < 131434)
+#if (LINUX_VERSION_CODE < 0x02016a)
 #error "You need kernel 2.1.106+ or 2.2.x"
 #endif
 
-#define VERSION "1.0.0"
+#define VERSION "1.0.1"
 
 #define GR_TUNER_UP 0
 #define GR_TUNER_DOWN 1
@@ -42,9 +42,14 @@
 #define GR_TUNER_STEP_LARGE 200
 #define GR_TUNER_STEP_SMALL 10
 
-/* FIXME: These should be replaced with values from a query */
+#ifndef WIDE_FREQ
 #define GR_FREQ_MIN 87900
 #define GR_FREQ_MAX 108100
+#else
+#define GR_FREQ_MIN 76100
+#define GR_FREQ_MAX 108900
+#endif
+
 #define GR_FREQ_DEFAULT 100100
 #define GR_VOL_MIN 0
 #define GR_VOL_MAX 10
@@ -55,6 +60,8 @@ typedef struct
     char dev_name[128];
     int fd;
     int freq;
+    int freq_max;
+    int freq_min;
     int vol;
     int muted;
     int mem[8];
