@@ -1,12 +1,8 @@
 /* interface.c
- * Contains detection routines for the kernel and direct interfaces to the
- * card.
+ * Contains detection routines for the kernel interface to the card.
  */
 
-/* (c) 1998 by Keith Wesolowski (wesolows@cs.unr.edu) 
-
- * Portions of the direct i/o routines are (c)1996 Thomas Lehmann,
- * Gideon LaGrange, and/or Franz Brinkman. 
+/* (c) 1998-2000 by Keith Wesolowski (wesolows@foobazco.org)
 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +21,8 @@
 
 #include <fcntl.h>
 #include <unistd.h>
+#include <sys/ioctl.h>
+#include <linux/videodev.h>
 #include "gradio.h"
 
 extern radio_status gr_stat;
@@ -34,9 +32,25 @@ void gradio_get_interface (void)
 
     /* First determine whether we can use the kernel interface */
     int fd;
-    if ((fd = open (gr_stat.dev_name, O_RDONLY)) > 0)
+    struct video_tuner vt;
+    double fact;
+        if ((fd = open (gr_stat.dev_name, O_RDONLY)) > 0) {
 	gr_stat.fd = fd;
-    else {
+	vt.tuner = 0;
+	fact = gradio_get_freq_fact ();
+	if (ioctl (fd, VIDIOCGTUNER, &vt)) {
+	    gr_stat.freq_max = GR_FREQ_MAX;
+	    gr_stat.freq_min = GR_FREQ_MIN;
+	} else {
+#ifdef OVERRIDE_FREQ
+	    gr_stat.freq_max = GR_FREQ_MAX;
+	    gr_stat.freq_min = GR_FREQ_MIN;
+#else
+	    gr_stat.freq_max = (int)(vt.rangehigh / fact);
+	    gr_stat.freq_min = (int)(vt.rangelow / fact);
+#endif
+	}
+    } else {
 	fprintf (stderr, "No interface found!\n");
 	exit (1);
     }
