@@ -3,7 +3,7 @@
  * the kernel interface
  */
 
-/* (c) 1998 by Keith Wesolowski (wesolows@cs.unr.edu) 
+/* (c) 1998-2000 by Keith Wesolowski (wesolows@foobazco.org)
 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,10 +48,10 @@ int gradio_setfreq (int fr)
     struct video_audio va;
     unsigned long xl_freq;
 
-    if (fr > GR_FREQ_MAX)
-	fr = GR_FREQ_MAX;
-    if (fr < GR_FREQ_MIN)
-	fr = GR_FREQ_MIN;
+    if (fr > gr_stat.freq_max)
+	fr = gr_stat.freq_max;
+    if (fr < gr_stat.freq_min)
+	fr = gr_stat.freq_min;
 
     xl_freq = (unsigned long)(fr*gradio_get_freq_fact ()
 			      + 0.5);
